@@ -70,7 +70,7 @@ class ObservationSerializer(serializers.ModelSerializer):
 
     def update(self, instance, validated_data):
         """Updates observation object with validated data"""
-        super(ObservationSerializer, self).update(instance, validated_data)
+        super().update(instance, validated_data)
         return instance
 
     def get_transmitter(self, obj):
@@ -245,21 +245,19 @@ class NewObservationSerializer(serializers.Serializer):
     start = serializers.DateTimeField(
         input_formats=['%Y-%m-%d %H:%M:%S.%f', '%Y-%m-%d %H:%M:%S'],
         error_messages={
-            'invalid':
-            'Start datetime should have either \'%Y-%m-%d %H:%M:%S.%f\' or \'%Y-%m-%d %H:%M:%S\' '
+            'invalid': 'Start datetime should have either \'%Y-%m-%d %H:%M:%S.%f\' or '
+            '\'%Y-%m-%d %H:%M:%S\' '
             'format.',
-            'required':
-            'Start(\'start\' key) datetime is required.'
+            'required': 'Start(\'start\' key) datetime is required.'
         }
     )
     end = serializers.DateTimeField(
         input_formats=['%Y-%m-%d %H:%M:%S.%f', '%Y-%m-%d %H:%M:%S'],
         error_messages={
-            'invalid':
-            'End datetime should have either \'%Y-%m-%d %H:%M:%S.%f\' or \'%Y-%m-%d %H:%M:%S\' '
+            'invalid': 'End datetime should have either \'%Y-%m-%d %H:%M:%S.%f\' or '
+            '\'%Y-%m-%d %H:%M:%S\' '
             'format.',
-            'required':
-            'End datetime(\'end\' key) is required.'
+            'required': 'End datetime(\'end\' key) is required.'
         }
     )
     ground_station = serializers.PrimaryKeyRelatedField(
