@@ -1,3 +1,4 @@
+# pylint: disable=C0415
 """SatNOGS Network celery task workers"""
 import os
 
@@ -24,53 +25,56 @@ APP.autodiscover_tasks()
 @APP.task
 def update_future_observations_with_new_tle_sets():
     """Wrapper task for 'update_future_observations_with_new_tle_sets' shared task"""
-    from network.base.tasks import (  # pylint: disable=C0415
-        update_future_observations_with_new_tle_sets as periodic_task
-    )
+    from network.base.tasks import update_future_observations_with_new_tle_sets as periodic_task
     periodic_task()
 
 
 @APP.task
 def fetch_data():
     """Wrapper task for 'fetch_data' shared task"""
-    from network.base.tasks import fetch_data as periodic_task  # pylint: disable=C0415
+    from network.base.tasks import fetch_data as periodic_task
     periodic_task()
 
 
 @APP.task
 def clean_observations():
     """Wrapper task for 'clean_observations' shared task"""
-    from network.base.tasks import clean_observations as periodic_task  # pylint: disable=C0415
+    from network.base.tasks import clean_observations as periodic_task
     periodic_task()
 
 
 @APP.task
 def station_status_update():
     """Wrapper task for 'station_status_update' shared task"""
-    from network.base.tasks import station_status_update as periodic_task  # pylint: disable=C0415
-    periodic_task()
-
-
-@APP.task
-def stations_cache_rates():
-    """Wrapper task for 'stations_cache_rates' shared task"""
-    from network.base.tasks import stations_cache_rates as periodic_task  # pylint: disable=C0415
+    from network.base.tasks import station_status_update as periodic_task
     periodic_task()
 
 
 @APP.task
 def notify_for_stations_without_results():
     """Wrapper task for 'notify_for_stations_without_results' shared task"""
-    from network.base.tasks import notify_for_stations_without_results as \
-        periodic_task  # pylint: disable=C0415
+    from network.base.tasks import notify_for_stations_without_results as periodic_task
+    periodic_task()
+
+
+@APP.task
+def zip_audio_files():
+    """Wrapper task for 'zip_audio_files' shared task"""
+    from network.base.tasks import zip_audio_files as periodic_task
+    periodic_task()
+
+
+@APP.task
+def archive_audio_zip_files():
+    """Wrapper task for 'archive_audio_zip_files' shared task"""
+    from network.base.tasks import archive_audio_zip_files as periodic_task
     periodic_task()
 
 
 @APP.task
 def find_and_rate_failed_observations():
     """Wrapper task for 'find_and_rate_failed_observations' shared task"""
-    from network.base.rating_tasks import find_and_rate_failed_observations as \
-        periodic_task  # pylint: disable=C0415
+    from network.base.rating_tasks import find_and_rate_failed_observations as periodic_task
     periodic_task()
 
 
@@ -87,16 +91,20 @@ def setup_periodic_tasks(sender, **kwargs):  # pylint: disable=W0613
 
     sender.add_periodic_task(RUN_HOURLY, station_status_update.s(), name='station_status_update')
 
-    sender.add_periodic_task(RUN_HOURLY, clean_observations.s(), name='clean_observations')
-
-    sender.add_periodic_task(RUN_HOURLY, stations_cache_rates.s(), name='stations_cache_rates')
-
     sender.add_periodic_task(
         settings.OBS_NO_RESULTS_CHECK_PERIOD,
         notify_for_stations_without_results.s(),
         name='notify_for_stations_without_results'
     )
 
+    if settings.ARCHIVE_ZIP_FILES:
+        sender.add_periodic_task(
+            RUN_HOURLY, archive_audio_zip_files.s(), name='archive_audio_zip_files'
+        )
+
+    if settings.ZIP_AUDIO_FILES:
+        sender.add_periodic_task(RUN_EVERY_15_MINUTES, zip_audio_files.s(), name='zip_audio_files')
+
     sender.add_periodic_task(
         RUN_EVERY_15_MINUTES,
         find_and_rate_failed_observations.s(),
